<?php
/**
 * @file
 * commerce_eu_vat.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function commerce_eu_vat_default_rules_configuration() {

  $rule = rules_or(array(
    'commerce_order' => array(
      'label' => t('Commerce Order'),
      'type' => 'commerce_order',
    ),
    'country_list' => array(
      'label' => t('List of Countries'),
      'type' => 'list<text>',
    ),
  ));
  $rule->label = t('Check Place of Supply');

  $rule->condition('component_commerce_eu_vat_rules_place_of_supply_billing', array('commerce_order:select' => 'commerce-order', 'country_list:select' => 'country_list'));

  $configs['commerce_eu_vat_rules_place_of_supply'] = $rule;

  $rule = rules_and(array(
    'commerce_order' => array(
      'label' => t('Commerce Order'),
      'type' => 'commerce_order',
    ),
    'country_list' => array(
      'label' => t('List of Countries'),
      'type' => 'list<text>',
    ),
  ));
  $rule->label = t('Check Place of Supply - Billing');

  $rule
    ->condition('entity_has_field', array('entity:select' => 'commerce-order', 'field' => 'commerce_customer_billing'))
    ->condition('component_commerce_eu_vat_rules_place_of_supply_profile_country', array('customer_profile:select' => 'commerce-order:commerce-customer-billing'));

  $configs['commerce_eu_vat_rules_place_of_supply_billing'] = $rule;

  if (module_exists('commerce_shipping')) {
    $rule = rules_and(array(
      'commerce_order' => array(
        'label' => t('Commerce Order'),
        'type' => 'commerce_order',
      ),
      'country_list' => array(
        'label' => t('List of Countries'),
        'type' => 'list<text>',
      ),
    ));
    $rule->label = t('Check Place of Supply - Shipping');

    $rule
      ->condition('entity_has_field', array('entity:select' => 'commerce-order', 'field' => 'commerce_customer_shipping'))
      ->condition('component_commerce_eu_vat_rules_place_of_supply_profile_country', array('customer_profile:select' => 'commerce-order:commerce-customer-shipping'));

    $configs['commerce_eu_vat_rules_place_of_supply_shipping'] = $rule;
  }

  $rule = rules_and(array(
    'customer_profile' => array(
      'label' => t('Customer Profile'),
      'type' => 'commerce_customer_profile',
    ),
    'country_list' => array(
      'label' => t('List of Countries'),
      'type' => 'list<text>',
    ),
  ));
  $rule->label = t('Check Place of Supply - Profile Country');

  $rule->condition(rules_and()
    ->condition('entity_has_field', array('entity:select' => 'customer-profile', 'field' => 'commerce_customer_address'))
    ->condition('data_is', array('data:select' => 'customer-profile:commerce-customer-address:country', 'op' => 'IN', 'value:select' => 'country-list'))
  );

  $configs['commerce_eu_vat_rules_place_of_supply_profile_country'] = $rule;

  return $configs;
}

/**
 * Impliments hook_default_rules_configuration_alter().
 */
function commerce_eu_vat_default_rules_configuration_alter(&$configs) {
  $configs['commerce_tax_type_eu_vat']
    ->condition(rules_or()
      ->condition('component_commerce_eu_vat_rules_place_of_supply', array('commerce_order:select' => 'commerce-line-item:order', 'country_list' => array_keys(_commerce_eu_vat_eu_countries())))
      ->condition(rules_and()
        ->condition('entity_has_field', array('entity:select' => 'commerce-line-item:order', 'field' => 'commerce_customer_billing'))
        ->condition('data_is_empty', array('data:select' => 'commerce-line-item:order:commerce-customer-billing'))
        ->condition('commerce_eu_vat_rules_site_is_in_eu')
      ));

  if (module_exists('commerce_shipping')) {
    $configs['commerce_eu_vat_rules_place_of_supply']
      ->condition('component_commerce_eu_vat_rules_place_of_supply_shipping', array('commerce_order:select' => 'commerce-order', 'country_list:select' => 'country_list'));

    $configs['commerce_eu_vat_rules_place_of_supply_billing']
      ->condition('entity_has_field', array('entity:select' => 'commerce-order', 'field' => 'commerce_customer_shipping'))
      ->condition('data_is_empty', array('data:select' => 'commerce-order:commerce-customer-shipping'));
  }

  // Add a condition to each component.
  $tax_rates = commerce_tax_rates();

  foreach ($tax_rates as $tax_rate) {
    if (strpos($tax_rate['type'], 'eu_vat') === 0) {
      $configs[$tax_rate['rules_component']]
        ->condition('entity_has_field', array('entity:select' => 'commerce-line-item', 'field' => 'commerce_product'))
        ->condition('entity_has_field', array('entity:select' => 'commerce-line-item:commerce-product', 'field' => 'commerce_eu_vat_rate'))
        ->condition('list_contains', array('list:select' => 'commerce-line-item:commerce-product:commerce_eu_vat_rate', 'item' => $tax_rate['name']));
    }
  }
}
